Type Alias RcBox

pub type RcBox<'a, T, A = Global> = Genrc<'a, T, Nonatomic, A, true>;
Rc<T> that is known to be the unique strong pointer to its referent, so it can be used mutably until downgrading by calling RcBox::shared().

Aliased Type

pub struct RcBox<'a, T, A = Global> { /* private fields */ }